function varargout = matlab_market(varargin)
% MATLAB_MARKET Application M-file for untitled.fig
%   MATLAB_MARKET, by itself, creates a new MATLAB_MARKET or raises the existing
%   singleton*.
%
%   H = MATLAB_MARKET returns the handle to a new MATLAB_MARKET or the handle to
%   the existing singleton*.
%
%   MATLAB_MARKET('Property','Value',...) creates a new MATLAB_MARKET using the
%   given property value pairs or adjusts settings on the existing singleton*.
%   Unrecognized properties are passed via varargin to untitled_OpeningFcn.
%
%   *See GUI Options - GUI allows only one instance to run (singleton).
%
%   MATLAB_MARKET('Callback') and MATLAB_MARKET('Callback', hObject, ...) call the
%   named function in MATLAB_MARKET.M with the given input arguments.
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help untitled

% Last Modified by GUIDE v2.5 15-Apr-2002 07:57:36

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_Name  = mfilename;
gui_main;
% End initialization code - DO NOT EDIT


% --- Executes just before matlab_market is made visible.
function matlab_market_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   unrecognized PropertyName/PropertyValue pairs from the
%            command line (see VARARGIN)

% Choose default command line output for matlab_market
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes matlab_market wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = matlab_market_OutputFcn(hObject, eventdata, handles)
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes on button press in pushbutton1.
function pushbutton1_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)


% --- Executes during object creation, after setting all properties.
function edit3_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background, change
%       'usewhitebg' to 0 to use default.  See ISPC and COMPUTER.
usewhitebg = 1;
if usewhitebg
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end



function edit3_Callback(hObject, eventdata, handles)
% hObject    handle to edit3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3 as text
%        str2double(get(hObject,'String')) returns contents of edit3 as a double


% --------------------------------------------------------------------
function Untitled_1_Callback(hObject, eventdata, handles)
% hObject    handle to Untitled_1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)


